Attribute VB_Name = "Tidy"
'
' Tidy.bas - Integration with Tidy in Microsoft FrontPage 2000/2002
'
' Based on code by Christoph Schneegans <mailto:Christoph@Schneegans.de>
' See <http://www.schneegans.de/frontpage-vba/tidy.html>
'

Option Explicit

' Specifies Path to Tidy executable...
Const TIDY_PROGRAM_FILE = "C:\Program Files\Validator\tidy.exe"

' Specifies path to Tidy configuration file...
Const TIDY_CONFIG_FILE = "C:\Program Files\Validator\tidy.cfg"

' Specifies path to Tidy error files....
Const TIDY_ERROR_FILE = "C:\Program Files\Validator\tidy_errors.txt"

' Specifies path to Tidy temporary file...
Const TIDY_TEMP_FILE = "C:\Program Files\Validator\tidy.tmp"

'************************************
' TIDY_FILE
'
'
Sub Tidy_File()

  Dim bFlipToHTMLSource As Boolean
  bFlipToHTMLSource = False
  
  If ActivePageWindow Is Nothing Then
    MsgBox "Please open a file in the Frontpage Editor.", _
      vbOKOnly Or vbCritical
    Exit Sub
  End If

  If Not ActivePageWindow.ViewMode = fpPageViewNormal Then
    bFlipToHTMLSource = True
    'If MsgBox("The Tidy macro requires the Normal view mode. Should I shift to Normal view for you?", vbQuestion Or vbYesNo) = vbYes Then
      ActivePageWindow.ViewMode = fpPageViewNormal
    'Else
    '  Exit Sub
    'End If
  End If

  Dim doc As FPHTMLDocument
  Set doc = ActivePageWindow.Document

  Dim fs
  Set fs = CreateObject("Scripting.FileSystemObject")
  Dim ts
  Set ts = fs.CreateTextFile(TIDY_TEMP_FILE)
    
  'Dim str As String
  'str = doc.DocumentHTML
  'str = ReplaceTest(str, "<span[\s]+lang=\x22[^\x22]*\x22[\s]*>([\s\S]*)</span>", "$1")
  'str = ReplaceTest(str, "<p></p>", "")
  'str = ReplaceTest(str, "<p>&nbsp;</p>", "")
    
  ' Load it into the active document of FrontPage
  On Error GoTo TidyError
  ts.Write doc.DocumentHTML
  ts.Close
  
  Dim strCmd As String
  strCmd = Chr(34) & TIDY_PROGRAM_FILE & Chr(34) & " -f " & Chr(34) & TIDY_ERROR_FILE & Chr(34) & _
           " -config " & Chr(34) & TIDY_CONFIG_FILE & Chr(34) & " " & Chr(34) & TIDY_TEMP_FILE & Chr(34)

  ' Excecute the tidy command line...
  ' For more information see <http://support.microsoft.com/support/kb/articles/Q129/7/96.asp>
  If ExecCmd(strCmd) > 1 Then
    Err.Raise vbObjectError + 513 ' Raise a user-defined error
    Exit Sub
  End If

  ' Open the result file (the temporary file)...
  Set ts = fs.OpenTextFile(TIDY_TEMP_FILE, 1)  ' 1=ForReading

  ' Load it into the active document of FrontPage  On Error GoTo TidyError
  doc.DocumentHTML = ts.ReadAll
  'On Error GoTo 0
  
  If bFlipToHTMLSource Then
    ActivePageWindow.ViewMode = fpPageViewHtml
  End If
  
  Dim es
  'Read the TIDY_ERROR_FILE and copy the content into the Form_output
  Set es = fs.OpenTextFile(TIDY_ERROR_FILE, 1)  ' 1=ForReading
  Form_output.TextBox_output.Text = es.ReadAll
  Form_output.Caption = TIDY_ERROR_FILE
  Form_output.Show
  
  Exit Sub

TidyError:
  MsgBox "Tidy could not execute correctly. No changes have been carried out." & Chr(10) & "Error # " & CStr(Err.Number) & " " & Err.Description, vbOKOnly Or vbCritical
End Sub

' *******************************************
' TIDY_WEB
'
'
Sub Tidy_Web()

'Ohne Web geht es nicht...
If ActiveWeb Is Nothing Then
  MsgBox "Open a Web!", vbOKOnly Or _
    vbCritical
  Exit Sub
End If

'Alle Editor-Fenster mssen geschlossen sein.
If Not ActivePageWindow Is Nothing Then
  MsgBox "All documents in the editor must be closed.", _
    vbOKOnly Or vbCritical
  Exit Sub
End If

'Das Verzeichnis, in dem das Web gespeichert ist.
Dim WebDir As String

'Speichert alle Dateien inklusive Pfad.
Dim FileList As String

Dim strCmd As String

With ActiveWeb.Properties
  
  'Es mu zwischen datentrger- und serverbasierten Webs
  'unterschieden werden.
  'Datentrgerbasierte Webs sind einfach.
  If .Item("vti_webservertype") = "diskweb" Then
    WebDir = ActiveWeb.RootFolder.Name
    
  'Bei serverbasierten Webs lt sich der Speicherordner
  'nicht automatisch feststellen.
  Else
      
    On Error GoTo NotFound
    WebDir = .Item("Speicherordner")
    On Error GoTo 0
    GoTo Continue
      
NotFound:
    On Error GoTo 0
    Do
      WebDir = InputBox("Geben Sie das Verzeichnis an, " & _
        "in dem das aktuelle Web gespeichert wird " & _
        "(z.B. c:\inetpub\wwwroot\meinweb).", "Tidy")
      If WebDir = "" Then
        Exit Sub
      ElseIf Dir(WebDir, vbDirectory) = "" Then
        MsgBox "Der Verzeichnisname ist ungltig.", _
          vbOKOnly Or vbCritical
      Else
        Exit Do
      End If
    Loop
    .Add "Speicherordner", WebDir
    .ApplyChanges

  End If
  
End With
  
Continue:
  
'Rekursiv alle Ordner des Webs durchlaufen.
AddFiles ActiveWeb.RootFolder, FileList, WebDir

'Tidy-Aufruf zusammenstellen.
strCmd = TIDY_PROGRAM_FILE & " -f " & TIDY_ERROR_FILE & _
  " -config " & TIDY_CONFIG_FILE & FileList

'Tidy starten.
ExecCmd strCmd

If MsgBox("Sollen die Meldungen von Tidy angezeigt werden?", _
  vbYesNo Or vbQuestion) = vbYes Then
  Shell Environ("WINDIR") & "\notepad.exe " & TIDY_ERROR_FILE
End If
  
End Sub

Private Sub AddFiles(ByRef myFolder As WebFolder, ByRef _
  FileList As String, ByVal WebDir As String)

  Dim wf As WebFile
  Dim sf As WebFolder

  For Each wf In myFolder.Files
    If IsHTMLFile(wf.Name) Then
      FileList = FileList & " """ & WebDir & "\" & _
        wf.Name & """"
    End If
  Next
  
  For Each sf In myFolder.Folders
    If Not sf.IsWeb Then
      AddFiles sf, FileList, WebDir & "\" & sf.Name
    End If
  Next
  
End Sub

'Bestimmt, ob eine Datei ein HTML-Dokument sein kann.
'Geprft wird, ob die Erweiterung "htm", "html" oder "asp" ist.
Function IsHTMLFile(ByVal Filename As String) As Boolean
 
IsHTMLFile = ( _
 LCase(Right(Filename, 4)) = "html" Or _
 LCase(Right(Filename, 3)) = "htm" Or _
 LCase(Right(Filename, 3)) = "asp")

End Function


Function ReplaceTest(str1, patrn, replStr)
  Dim regEx
  Dim bOK As Boolean
  Set regEx = CreateObject("VBScript.RegExp")
  regEx.Pattern = patrn            ' Set pattern.
  'regEx.Pattern = "<span[\s]+lang=\x22[^\x22]*\x22[\s]*>([.\n]*)</span>"
  regEx.Global = True
  'bOK = regEx.Test(str1)
  
  'Dim str2 As String
  'str2 = regEx.Replace(str1, replStr)   ' Make replacement.
  'MsgBox str2
  'ReplaceTest = str1
  While regEx.Test(str1)
    str1 = regEx.Replace(str1, replStr)   ' Make replacement.
  Wend
  
  ReplaceTest = str1
End Function

